<?php
// $Id: chameleon.theme,v 1.14 2004/07/08 16:04:06 dries Exp $

engine_init("drupal");

function template_page($content, $title = NULL, $breadcrumb = NULL) {
  global $theme;

  if (isset($title)) {
    drupal_set_title($title);
  }

  if (isset($breadcrumb)) {
    drupal_set_breadcrumb($breadcrumb);
  }
  
  if ($theme['settings']['toggle_logo']) {
    if ($theme['settings']['default_logo']) {
      $logo = $theme['style_dir'] . '/logo.png'; 
    }
    elseif ($theme['settings']['logo_path']) {
      $logo = $theme['settings']['logo_path'];
    }
  }

  $output  = "<!DOCTYPE html PUBLIC \"-//W3C//DTD XHTML 1.0 Strict//EN\" \"http://www.w3.org/TR/xhtml1/DTD/xhtml1-strict.dtd\">\n";
  $output .= "<html xmlns=\"http://www.w3.org/1999/xhtml\" lang=\"en\" xml:lang=\"en\">\n";
  $output .= "<head>\n";
  $output .= " <title>". ($title ? $title ." | ". variable_get("site_name", "drupal") : variable_get("site_name", "drupal") ." | ". variable_get("site_slogan", "")) ."</title>\n";
  $output .= drupal_get_html_head();
  $output .= " <link rel=\"stylesheet\" type=\"text/css\" href=\"" . $theme["template_dir"] . "/common.css\" />\n";
  $output .= " <link rel=\"stylesheet\" type=\"text/css\" href=\"" . $theme["style_file"] . "\" />\n";
  $output .= "</head>";
  $output .= "<body". theme_onload_attribute() .">\n";
  $output .= " <div id=\"header\">";
  
  if ($logo) {
    $output .= "  <a href=\"./\" title=\"Home\"><img src=\"$logo\" alt=\"Home\" /></a>";
  } 
  if ($theme['settings']['toggle_name']) {
    $output .= "  <h1 class=\"site-name title\">". l(variable_get("site_name", "drupal"), ""). "</h1>";
  }
  
  if ($theme['settings']['toggle_slogan']) {
    $output .= "  <span class=\"site-slogan\">". variable_get("site_slogan", "") . "</span>";
  }

  if ($theme['settings']['primary_links']) {
    $links = $theme['settings']['primary_links'];
  }
  else {
    $links = link_page();
  }


  $output .= " <br \>\n";
  $output .= " </div>\n";
  $output .= " <div class=\"navlinks\">";
  $output .= ($theme['settings']['toggle_primary_links'] ? "<div class=\"primary\">$links</div>" : '');
  $output .= ($theme['settings']['toggle_secondary_links'] ? "<div class=\"secondary\">" . $theme['settings']['secondary_links'] . "</div>" : '');
  $output .= " </div>\n"; 

  $output .= " <table>\n";
  $output .= "  <tr>\n";

  if ($blocks = theme_blocks("left")) {
    $output .= "   <td id=\"sidebar-left\">$blocks</td>\n";
  }

  $output .= "   <td id=\"main\">\n";

  if ($title = drupal_get_title()) {
    $output .= theme("breadcrumb", drupal_get_breadcrumb());
    $output .= "<h2>$title</h2>";
  }

  if ($tabs = theme('menu_local_tasks')) {
    $output .= $tabs;
  }

  if ($help = menu_get_active_help()) {
    $output .= "<div id=\"help\">$help</div><hr />";
  }

  $output .= theme_status_messages();

  $output .= "\n<!-- begin content -->\n";
  $output .= $content;
  $output .= "\n<!-- end content -->\n";

  if ($footer = variable_get('site_footer', '')) {
    $output .= " <div id=\"footer\">$footer</div>\n";
  }

  $output  .= "   </td>\n";

  if ($blocks = theme_blocks("right")) {
    $output .= "   <td id=\"sidebar-right\">$blocks</td>\n";
  }

  $output .= "  </tr>\n";
  $output .= " </table>\n";

  $output .=  theme_closure();
  $output .= " </body>\n";
  $output .= "</html>\n";

  return $output;
}

function template_node($node, $main = 0, $page = 0) {
  global $theme;

  $output  = "<div class=\"node\">\n";

  if (!$page) {
    $output .= " <h2 class=\"title\">". ($main ? l($node->title, "node/$node->nid") : $node->title) ."</h2>\n";
  }

  $output .= " <div class=\"content\">\n";

  if ($main && $node->teaser) {
    $output .= $node->teaser;
  }
  else {
    $output .= $node->body;
  }

  $output .= " </div>\n";

  if ($theme['settings']['toggle_node_info_' . $node->type]) {
    $submitted = array(t("By %author at %date", array('%author' => format_name($node), '%date' => format_date($node->created, 'small'))));
  }

  if (module_exist('taxonomy')) {
    $terms = taxonomy_link("taxonomy terms", $node);
  }

  if ($links = link_node($node, $main)) {
    $output .= " <div class=\"links\">". theme('links', array_merge($submitted, $terms, $links)) ."</div>\n";
  }

  $output .= "</div>\n";

  return $output;
}

function template_comment($comment, $link = "") {

  $submitted = array(t('By %author at %date', array('%author' => format_name($comment), '%date' => format_date($comment->timestamp. 'small'))));
  $links = array($link);

  $output  = "<div class=\"comment\">\n";
  $output .= " <h3 class=\"title\">". l($comment->subject, $_GET['q'], NULL, NULL, "comment-$comment->cid") ."</h3>\n";
  $output .= " <div class=\"content\">". $comment->comment ."</div>\n";
  $output .= " <div class=\"links\">". theme('links', array_merge($submitted, $links)) ."</div>\n";
  $output .= "</div>\n";

  return $output;
}
?>
